gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-exchange] branch master updated: -doxygen fixes


From: gnunet
Subject: [taler-exchange] branch master updated: -doxygen fixes
Date: Sat, 24 Sep 2022 14:21:05 +0200

This is an automated email from the git hooks/post-receive script.

grothoff pushed a commit to branch master
in repository exchange.

The following commit(s) were added to refs/heads/master by this push:
     new 2961c9b3 -doxygen fixes
2961c9b3 is described below

commit 2961c9b3f6f3e3d1881a1c850d5ec4ddc33669cf
Author: Christian Grothoff <christian@grothoff.org>
AuthorDate: Sat Sep 24 14:21:03 2022 +0200

    -doxygen fixes
---
 src/include/taler_crypto_lib.h       |  6 ++++++
 src/include/taler_exchange_service.h | 14 +++++++-------
 2 files changed, 13 insertions(+), 7 deletions(-)

diff --git a/src/include/taler_crypto_lib.h b/src/include/taler_crypto_lib.h
index 2527362b..2977ccf3 100644
--- a/src/include/taler_crypto_lib.h
+++ b/src/include/taler_crypto_lib.h
@@ -3111,6 +3111,9 @@ TALER_wallet_reserve_open_deposit_verify (
 /**
  * Sign a request to close a reserve.
  *
+ * @param request_timestamp when was the request created
+ * @param h_payto where to send the funds (NULL allowed to send
+ *        to origin of the reserve)
  * @param reserve_priv key identifying the reserve
  * @param[out] reserve_sig resulting signature
  */
@@ -3125,6 +3128,9 @@ TALER_wallet_reserve_close_sign (
 /**
  * Verify wallet request to close an account.
  *
+ * @param request_timestamp when was the request created
+ * @param h_payto where to send the funds (NULL/all zeros
+ *        allowed to send to origin of the reserve)
  * @param reserve_pub account’s public key
  * @param reserve_sig the signature made with purpose 
#TALER_SIGNATURE_WALLET_RESERVE_CLOSE
  * @return #GNUNET_OK if the signature is valid
diff --git a/src/include/taler_exchange_service.h 
b/src/include/taler_exchange_service.h
index 5899df95..cc19885c 100644
--- a/src/include/taler_exchange_service.h
+++ b/src/include/taler_exchange_service.h
@@ -5324,7 +5324,7 @@ TALER_EXCHANGE_reserves_open (
  * Cancel a reserve status request.  This function cannot be used
  * on a request handle if a response is already served for it.
  *
- * @param rsh the reserve request handle
+ * @param roh the reserve open request handle
  */
 void
 TALER_EXCHANGE_reserves_open_cancel (
@@ -5416,11 +5416,11 @@ TALER_EXCHANGE_reserves_get_attestable (
  * Cancel a request to get attestable attributes.  This function cannot be used
  * on a request handle if a response is already served for it.
  *
  * @param rsh the reserve request handle
  */
 void
 TALER_EXCHANGE_reserves_get_attestable_cancel (
-  struct TALER_EXCHANGE_ReservesGetAttestHandle *roh);
+  struct TALER_EXCHANGE_ReservesGetAttestHandle *rgah);
 
 
 /**
@@ -5499,11 +5499,11 @@ TALER_EXCHANGE_reserves_attest (
  * Cancel a reserve status request.  This function cannot be used
  * on a request handle if a response is already served for it.
  *
  * @param rsh the reserve request handle
  */
 void
 TALER_EXCHANGE_reserves_attest_cancel (
-  struct TALER_EXCHANGE_ReservesAttestHandle *roh);
+  struct TALER_EXCHANGE_ReservesAttestHandle *rah);
 
 
 /* *********************  /reserves/$RID/close *********************** */
@@ -5583,10 +5583,10 @@ TALER_EXCHANGE_reserves_close (
  * Cancel a reserve status request.  This function cannot be used
  * on a request handle if a response is already served for it.
  *
  * @param rsh the reserve request handle
  */
 void
 TALER_EXCHANGE_reserves_close_cancel (
-  struct TALER_EXCHANGE_ReservesCloseHandle *roh);
+  struct TALER_EXCHANGE_ReservesCloseHandle *rch);
 
 #endif  /* _TALER_EXCHANGE_SERVICE_H */
@@ -5416,11 +5416,11 @@ TALER_EXCHANGE_reserves_get_attestable (
  * on a request handle if a response is already served for it.
  *
- * @param rsh the reserve request handle
+ * @param rgah the reserve get attestable request handle
  */
 void
@@ -5499,11 +5499,11 @@ TALER_EXCHANGE_reserves_attest (
  * on a request handle if a response is already served for it.
  *
- * @param rsh the reserve request handle
+ * @param rah the reserve attest request handle
  */
 void
@@ -5583,10 +5583,10 @@ TALER_EXCHANGE_reserves_close (
  * on a request handle if a response is already served for it.
  *
- * @param rsh the reserve request handle
+ * @param rch the reserve request handle
  */
 void

-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]